import os
import argparse


pRTC_usage = '''
================================ pRTC example commands ================================

# requires: ruby (bio-nwk, colorize, parallel, csv)

TreeSAK pRTC -i out -m mcmc.txt -rrtc /home-user/wzsong/DateArTree/rrtc_dir -ruby /home-user/sswang/program/ruby/bin/ruby -o mcmc_after_rrtc.txt

# A wrapper to perform the probability-based RTC dating approach originally proposed
# by Dr. Sishuo Wang from CUHK. Please see details in https://github.com/evolbeginner/rrtc

# format of rrtc file
symbiont_1,symbiont_2 host_1,host_2:prob
recipient_1,recipient_2	donor_1,donor_2:prob

=======================================================================================
'''


def pRTC(args):

    in_file     = args['i']
    mcmc_txt    = args['m']
    rrtc_dir    = args['rrtc']
    ruby_exe    = args['ruby']
    op_txt      = args['o']

    current_file_path = '/'.join(os.path.realpath(__file__).split('/')[:-1])
    do_rrtc_rb        = '%s/do_rrtc.rb'                             % current_file_path
    do_rrtc_cmd       = '%s %s --mcmctxt %s -i %s --rrtc %s > %s'   % (ruby_exe, do_rrtc_rb, mcmc_txt, in_file, rrtc_dir, op_txt)
    print(do_rrtc_cmd)
    os.system(do_rrtc_cmd)


if __name__ == '__main__':

    pRTC_parser = argparse.ArgumentParser(usage=pRTC_usage)
    pRTC_parser.add_argument('-i',     required=True,                   help='the file "out" generated by MCMCTree')
    pRTC_parser.add_argument('-m',     required=True,                   help='the file "mcmc.txt" generated by MCMCTree')
    pRTC_parser.add_argument('-rrtc',  required=True,                   help='the folder that contains the info of all RTCs')
    pRTC_parser.add_argument('-o',     required=True,                   help='output txt file')
    pRTC_parser.add_argument('-ruby',  required=False, default='ruby',  help='path to ruby executable file, default: ruby')
    args = vars(pRTC_parser.parse_args())
    pRTC(args)

'''

cd /home-user/wzsong/DateArTree/Marker_set_1_Williams_2020_43_arCOG_Marker2Tree_e30/s12_dating_wd/PA_75_DeltaLL_50_clock2_nsample500000_dating_wd
python3 /home-user/wzsong/Scripts/pRTC.py -o mcmc_after_rrtc.txt -i PA_75_DeltaLL_50_clock2_nsample500000_out.txt -m PA_75_DeltaLL_50_clock2_nsample500000_mcmc.txt -rrtc /home-user/wzsong/DateArTree/rrtc_dir -ruby /home-user/sswang/program/ruby/bin/ruby

'''
